@@ -63,6 +63,7 @@ class Api:
         self.allocation_report = api_client("allocationreport")
         self.available_currencies = api_client("availablecurrencies")
         self.api_keys = api_client("apikeys")
+        self.simple_assets = api_client("asset")
         self.assets = api_client("assets")
         self.ax_product = api_client("axproduct")
         self.burn_rates = api_client("burnrates")
@@ -74,6 +75,7 @@ class Api:
         self.creativepreview = api_client("creativepreview")
         self.creativepreviewhtml = api_client("creativepreview", accept="text/html")
         self.creatives = api_client("creatives")
+        self.creative_info = api_client("creatives/info")
         self.currency_conversion = api_client("currencyconversion")
         self.custom_event_types = api_client("customeventtypes")
         self.data_export = api_client("dataexports")
@@ -100,6 +102,7 @@ class Api:
         self.message_definitions = api_client("messagedefinitions")
         self.network_forecast = api_client("networkforecast")
         self.network_profiles = api_client("networkprofiles")
+        self.network_info = api_client("networkinfo")
         self.networks = api_client("networks")
         self.notes = api_client("notes")
         self.notifications = api_client("notifications")
